# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ListingResponseFilters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'type': 'str',
        'name': 'str',
        'values': 'list[ListingResponseFiltersValues]',
        'min_value': 'float',
        'max_value': 'float',
        'unit': 'str'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'name': 'name',
        'values': 'values',
        'min_value': 'minValue',
        'max_value': 'maxValue',
        'unit': 'unit'
    }

    def __init__(self, id=None, type=None, name=None, values=None, min_value=None, max_value=None, unit=None, local_vars_configuration=None):  # noqa: E501
        """ListingResponseFilters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._type = None
        self._name = None
        self._values = None
        self._min_value = None
        self._max_value = None
        self._unit = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if name is not None:
            self.name = name
        if values is not None:
            self.values = values
        if min_value is not None:
            self.min_value = min_value
        if max_value is not None:
            self.max_value = max_value
        if unit is not None:
            self.unit = unit

    @property
    def id(self):
        """Gets the id of this ListingResponseFilters.  # noqa: E501

        Identifier of the filter. Should be used as query parameter key, optionally followed by idSuffix from parameter value (only for NUMERIC filters).  # noqa: E501

        :return: The id of this ListingResponseFilters.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ListingResponseFilters.

        Identifier of the filter. Should be used as query parameter key, optionally followed by idSuffix from parameter value (only for NUMERIC filters).  # noqa: E501

        :param id: The id of this ListingResponseFilters.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this ListingResponseFilters.  # noqa: E501

        The type of the filter:   - *MULTI* - multiple choice filter,  - *SINGLE* - single select (dropdown) filter,  - *NUMERIC* - range of numeric values (search offers with value matching this range),  - *NUMERIC_SINGLE* - single numeric value (search offers with given value matching the range defined in offer),  - *TEXT* - filter allowing user to input any text.  # noqa: E501

        :return: The type of this ListingResponseFilters.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListingResponseFilters.

        The type of the filter:   - *MULTI* - multiple choice filter,  - *SINGLE* - single select (dropdown) filter,  - *NUMERIC* - range of numeric values (search offers with value matching this range),  - *NUMERIC_SINGLE* - single numeric value (search offers with given value matching the range defined in offer),  - *TEXT* - filter allowing user to input any text.  # noqa: E501

        :param type: The type of this ListingResponseFilters.  # noqa: E501
        :type: str
        """
        allowed_values = ["MULTI", "SINGLE", "NUMERIC", "NUMERIC_SINGLE", "TEXT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this ListingResponseFilters.  # noqa: E501

        Name of the filter.  # noqa: E501

        :return: The name of this ListingResponseFilters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListingResponseFilters.

        Name of the filter.  # noqa: E501

        :param name: The name of this ListingResponseFilters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def values(self):
        """Gets the values of this ListingResponseFilters.  # noqa: E501

        Available filter values.  # noqa: E501

        :return: The values of this ListingResponseFilters.  # noqa: E501
        :rtype: list[ListingResponseFiltersValues]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ListingResponseFilters.

        Available filter values.  # noqa: E501

        :param values: The values of this ListingResponseFilters.  # noqa: E501
        :type: list[ListingResponseFiltersValues]
        """

        self._values = values

    @property
    def min_value(self):
        """Gets the min_value of this ListingResponseFilters.  # noqa: E501

        Minimum valid value for filters of type NUMERIC.  # noqa: E501

        :return: The min_value of this ListingResponseFilters.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this ListingResponseFilters.

        Minimum valid value for filters of type NUMERIC.  # noqa: E501

        :param min_value: The min_value of this ListingResponseFilters.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def max_value(self):
        """Gets the max_value of this ListingResponseFilters.  # noqa: E501

        Maximum valid value for filters of type NUMERIC.  # noqa: E501

        :return: The max_value of this ListingResponseFilters.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this ListingResponseFilters.

        Maximum valid value for filters of type NUMERIC.  # noqa: E501

        :param max_value: The max_value of this ListingResponseFilters.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def unit(self):
        """Gets the unit of this ListingResponseFilters.  # noqa: E501

        Unit of the NUMERIC/NUMERIC_SINGLE filter.  # noqa: E501

        :return: The unit of this ListingResponseFilters.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this ListingResponseFilters.

        Unit of the NUMERIC/NUMERIC_SINGLE filter.  # noqa: E501

        :param unit: The unit of this ListingResponseFilters.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListingResponseFilters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListingResponseFilters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatible_product_dto import CompatibleProductDto  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibleProductDto(unittest.TestCase):
    """CompatibleProductDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibleProductDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatible_product_dto.CompatibleProductDto()  # noqa: E501
        if include_optional :
            return CompatibleProductDto(
                id = 'fc1058e6-a901-4b58-be4d-3d7e1368f63e', 
                text = 'AUDI A6 (4G2, 4GC, C7) 2014/09-2018/09 3.0 TDI quattro 326KM/240kW', 
                group = allegro_api.models.compatible_product_dto_group.CompatibleProductDto_group(
                    id = '19d71c872aa6c78663876a7e7bc7776d', ), 
                attributes = [{"id":"BRAND","values":["AUDI"]}]
            )
        else :
            return CompatibleProductDto(
        )

    def testCompatibleProductDto(self):
        """Test CompatibleProductDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.listing_response_offers import ListingResponseOffers  # noqa: E501
from allegro_api.rest import ApiException

class TestListingResponseOffers(unittest.TestCase):
    """ListingResponseOffers unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListingResponseOffers
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.listing_response_offers.ListingResponseOffers()  # noqa: E501
        if include_optional :
            return ListingResponseOffers(
                promoted = [
                    allegro_api.models.listing_offer.ListingOffer(
                        id = '2865624934', 
                        name = 'Buty damskie adidas', 
                        seller = allegro_api.models.offer_seller.OfferSeller(
                            id = '41846511', 
                            company = True, 
                            super_seller = True, ), 
                        promotion = allegro_api.models.offer_promotion.OfferPromotion(
                            emphasized = True, 
                            bold = True, 
                            highlight = True, ), 
                        delivery = allegro_api.models.offer_delivery.OfferDelivery(
                            available_for_free = True, 
                            lowest_price = allegro_api.models.offer_lowest_price.OfferLowestPrice(
                                amount = '123.45', 
                                currency = 'PLN', ), ), 
                        images = [
                            allegro_api.models.offer_images.OfferImages(
                                url = 'https://a.allegroimg.com/original/0129e7/f15ce8924166850eec3fb82bcd5s/BUTY-ADIDAS-DAMSKIE', )
                            ], 
                        selling_mode = allegro_api.models.offer_selling_mode.OfferSellingMode(
                            format = 'BUY_NOW', 
                            price = allegro_api.models.offer_price.OfferPrice(
                                amount = '123.45', 
                                currency = 'PLN', ), 
                            fixed_price = allegro_api.models.offer_fixed_price.OfferFixedPrice(
                                amount = '123.45', 
                                currency = 'PLN', ), 
                            popularity = 38, 
                            bid_count = 12, ), 
                        stock = allegro_api.models.offer_stock.OfferStock(
                            unit = 'UNIT', 
                            available = 23, ), 
                        vendor = allegro_api.models.offer_vendor.OfferVendor(
                            id = 'CHARYTATYWNI_ALLEGRO', 
                            url = 'http://charytatywni.allegro.pl/oferta-charytatywna-i1234567', ), 
                        category = allegro_api.models.offer_category.OfferCategory(
                            id = '257929', ), 
                        publication = allegro_api.models.offer_publication.OfferPublication(
                            ending_at = '2019-05-15T18:09:41.000Z', ), )
                    ], 
                regular = [
                    allegro_api.models.listing_offer.ListingOffer(
                        id = '2865624934', 
                        name = 'Buty damskie adidas', 
                        seller = allegro_api.models.offer_seller.OfferSeller(
                            id = '41846511', 
                            company = True, 
                            super_seller = True, ), 
                        promotion = allegro_api.models.offer_promotion.OfferPromotion(
                            emphasized = True, 
                            bold = True, 
                            highlight = True, ), 
                        delivery = allegro_api.models.offer_delivery.OfferDelivery(
                            available_for_free = True, 
                            lowest_price = allegro_api.models.offer_lowest_price.OfferLowestPrice(
                                amount = '123.45', 
                                currency = 'PLN', ), ), 
                        images = [
                            allegro_api.models.offer_images.OfferImages(
                                url = 'https://a.allegroimg.com/original/0129e7/f15ce8924166850eec3fb82bcd5s/BUTY-ADIDAS-DAMSKIE', )
                            ], 
                        selling_mode = allegro_api.models.offer_selling_mode.OfferSellingMode(
                            format = 'BUY_NOW', 
                            price = allegro_api.models.offer_price.OfferPrice(
                                amount = '123.45', 
                                currency = 'PLN', ), 
                            fixed_price = allegro_api.models.offer_fixed_price.OfferFixedPrice(
                                amount = '123.45', 
                                currency = 'PLN', ), 
                            popularity = 38, 
                            bid_count = 12, ), 
                        stock = allegro_api.models.offer_stock.OfferStock(
                            unit = 'UNIT', 
                            available = 23, ), 
                        vendor = allegro_api.models.offer_vendor.OfferVendor(
                            id = 'CHARYTATYWNI_ALLEGRO', 
                            url = 'http://charytatywni.allegro.pl/oferta-charytatywna-i1234567', ), 
                        category = allegro_api.models.offer_category.OfferCategory(
                            id = '257929', ), 
                        publication = allegro_api.models.offer_publication.OfferPublication(
                            ending_at = '2019-05-15T18:09:41.000Z', ), )
                    ]
            )
        else :
            return ListingResponseOffers(
        )

    def testListingResponseOffers(self):
        """Test ListingResponseOffers"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatible_products_list_dto import CompatibleProductsListDto  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibleProductsListDto(unittest.TestCase):
    """CompatibleProductsListDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibleProductsListDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatible_products_list_dto.CompatibleProductsListDto()  # noqa: E501
        if include_optional :
            return CompatibleProductsListDto(
                compatible_products = [{"id":"fc1058e6-a901-4b58-be4d-3d7e1368f63e","text":"AUDI A6 (4G2, 4GC, C7) 2014/09-2018/09 3.0 TDI quattro 326KM/240kW","group":{"id":"19d71c872aa6c78663876a7e7bc7776d"},"attributes":[{"id":"POWER_KW","values":["240"]},{"id":"MODEL_FROM","values":["2010/11"]},{"id":"BRAND","values":["AUDI"]},{"id":"POWER_HP","values":["326"]},{"id":"MODEL_TO","values":["2018/09"]},{"id":"ENGINE_CODE","values":["CVUB"]},{"id":"K_TYP_NR","values":["108441"]},{"id":"VERSION_FROM","values":["2014/09"]},{"id":"VERSION_TO","values":["2018/09"]},{"id":"MODEL","values":["A6 (4G2, 4GC, C7)"]},{"id":"BODY","values":["sedan"]},{"id":"TYPE","values":["3.0 TDI quattro"]}]}], 
                count = 1, 
                total_count = 1448
            )
        else :
            return CompatibleProductsListDto(
        )

    def testCompatibleProductsListDto(self):
        """Test CompatibleProductsListDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.user_rating_list_response import UserRatingListResponse  # noqa: E501
from allegro_api.rest import ApiException

class TestUserRatingListResponse(unittest.TestCase):
    """UserRatingListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserRatingListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.user_rating_list_response.UserRatingListResponse()  # noqa: E501
        if include_optional :
            return UserRatingListResponse(
                ratings = [
                    allegro_api.models.user_rating.UserRating(
                        answer = allegro_api.models.answer.Answer(
                            created_at = '2017-05-17T08:36:57.292+02:00', 
                            message = '0', ), 
                        buyer = allegro_api.models.user.User(
                            id = '0', 
                            login = '0', ), 
                        comment = '0', 
                        created_at = '2017-05-17T08:36:57.292+02:00', 
                        excluded_from_average_rates = False, 
                        id = '0', 
                        order = allegro_api.models.order.Order(
                            id = '0', 
                            offers = [
                                allegro_api.models.offer.Offer(
                                    additional_services = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                                        implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                                        return_policy = allegro_api.models.return_policy.ReturnPolicy(
                                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                                        warranty = allegro_api.models.warranty.Warranty(
                                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                                    attachments = [
                                        allegro_api.models.attachment.Attachment(
                                            id = '1928302_MANUAL_45d7a0f543e1b0d05e12a1aef5642efe63389a1d419fe9286d0f158044391fdce', )
                                        ], 
                                    category = allegro_api.models.category.Category(
                                        id = '0', ), 
                                    compatibility_list = allegro_api.models.compatibility_list.CompatibilityList(), 
                                    contact = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    delivery = allegro_api.models.delivery.Delivery(
                                        additional_info = '0', 
                                        handling_time = 'PDT12H30M5S', 
                                        shipment_date = '2018-04-01T08:00Z', 
                                        shipping_rates = allegro_api.models.just_id.JustId(
                                            id = '0', ), ), 
                                    description = allegro_api.models.standardized_description.StandardizedDescription(
                                        sections = [
                                            allegro_api.models.description_section.DescriptionSection(
                                                items = [
                                                    allegro_api.models.description_section_item.DescriptionSectionItem(
                                                        type = '0', )
                                                    ], )
                                            ], ), 
                                    ean = '0', 
                                    external = allegro_api.models.external_id.ExternalId(
                                        id = 'AH-129834', ), 
                                    id = '0', 
                                    images = [
                                        allegro_api.models.image_url.ImageUrl(
                                            url = '0', )
                                        ], 
                                    location = allegro_api.models.location.Location(
                                        city = '0', 
                                        country_code = '0', 
                                        post_code = '0', 
                                        province = '0', ), 
                                    name = '0', 
                                    parameters = [
                                        allegro_api.models.parameter.Parameter(
                                            id = '0', 
                                            range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                                from = '0', 
                                                to = '0', ), 
                                            values = [
                                                '0'
                                                ], 
                                            values_ids = [
                                                '0'
                                                ], )
                                        ], 
                                    payments = allegro_api.models.payments.Payments(
                                        invoice = '0', ), 
                                    product = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    promotion = allegro_api.models.promotion.Promotion(
                                        bold = True, 
                                        department_page = True, 
                                        emphasized = True, 
                                        emphasized_highlight_bold_package = True, 
                                        highlight = True, ), 
                                    publication = allegro_api.models.publication.Publication(
                                        duration = 'PDT12H30M5S', 
                                        ending_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        starting_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        status = 'INACTIVE', 
                                        ended_by = 'USER', 
                                        republish = False, ), 
                                    selling_mode = allegro_api.models.selling_mode.SellingMode(
                                        format = 'BUY_NOW', 
                                        price = null, 
                                        minimal_price = null, 
                                        starting_price = null, ), 
                                    size_table = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    stock = allegro_api.models.stock.Stock(
                                        available = 56, 
                                        unit = '0', ), 
                                    tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                                        id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', ), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    validation = allegro_api.models.validation.Validation(
                                        errors = [
                                            allegro_api.models.validation_error.ValidationError(
                                                code = '0', 
                                                details = '0', 
                                                message = '0', 
                                                path = '0', 
                                                user_message = '0', )
                                            ], 
                                        validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], ), 
                        rates = allegro_api.models.rates.Rates(
                            delivery_cost = 5, 
                            service = 5, ), 
                        recommended = False, 
                        removal = allegro_api.models.removal.Removal(
                            possible_to = '2017-05-17T08:36:57.292+02:00', 
                            request = allegro_api.models.removal_request.RemovalRequest(
                                created_at = '2017-05-17T08:36:57.292+02:00', 
                                message = '0', ), ), )
                    ]
            )
        else :
            return UserRatingListResponse(
                ratings = [
                    allegro_api.models.user_rating.UserRating(
                        answer = allegro_api.models.answer.Answer(
                            created_at = '2017-05-17T08:36:57.292+02:00', 
                            message = '0', ), 
                        buyer = allegro_api.models.user.User(
                            id = '0', 
                            login = '0', ), 
                        comment = '0', 
                        created_at = '2017-05-17T08:36:57.292+02:00', 
                        excluded_from_average_rates = False, 
                        id = '0', 
                        order = allegro_api.models.order.Order(
                            id = '0', 
                            offers = [
                                allegro_api.models.offer.Offer(
                                    additional_services = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                                        implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                                        return_policy = allegro_api.models.return_policy.ReturnPolicy(
                                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                                        warranty = allegro_api.models.warranty.Warranty(
                                            id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                                    attachments = [
                                        allegro_api.models.attachment.Attachment(
                                            id = '1928302_MANUAL_45d7a0f543e1b0d05e12a1aef5642efe63389a1d419fe9286d0f158044391fdce', )
                                        ], 
                                    category = allegro_api.models.category.Category(
                                        id = '0', ), 
                                    compatibility_list = allegro_api.models.compatibility_list.CompatibilityList(), 
                                    contact = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    delivery = allegro_api.models.delivery.Delivery(
                                        additional_info = '0', 
                                        handling_time = 'PDT12H30M5S', 
                                        shipment_date = '2018-04-01T08:00Z', 
                                        shipping_rates = allegro_api.models.just_id.JustId(
                                            id = '0', ), ), 
                                    description = allegro_api.models.standardized_description.StandardizedDescription(
                                        sections = [
                                            allegro_api.models.description_section.DescriptionSection(
                                                items = [
                                                    allegro_api.models.description_section_item.DescriptionSectionItem(
                                                        type = '0', )
                                                    ], )
                                            ], ), 
                                    ean = '0', 
                                    external = allegro_api.models.external_id.ExternalId(
                                        id = 'AH-129834', ), 
                                    id = '0', 
                                    images = [
                                        allegro_api.models.image_url.ImageUrl(
                                            url = '0', )
                                        ], 
                                    location = allegro_api.models.location.Location(
                                        city = '0', 
                                        country_code = '0', 
                                        post_code = '0', 
                                        province = '0', ), 
                                    name = '0', 
                                    parameters = [
                                        allegro_api.models.parameter.Parameter(
                                            id = '0', 
                                            range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                                from = '0', 
                                                to = '0', ), 
                                            values = [
                                                '0'
                                                ], 
                                            values_ids = [
                                                '0'
                                                ], )
                                        ], 
                                    payments = allegro_api.models.payments.Payments(
                                        invoice = '0', ), 
                                    product = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    promotion = allegro_api.models.promotion.Promotion(
                                        bold = True, 
                                        department_page = True, 
                                        emphasized = True, 
                                        emphasized_highlight_bold_package = True, 
                                        highlight = True, ), 
                                    publication = allegro_api.models.publication.Publication(
                                        duration = 'PDT12H30M5S', 
                                        ending_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        starting_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        status = 'INACTIVE', 
                                        ended_by = 'USER', 
                                        republish = False, ), 
                                    selling_mode = allegro_api.models.selling_mode.SellingMode(
                                        format = 'BUY_NOW', 
                                        price = null, 
                                        minimal_price = null, 
                                        starting_price = null, ), 
                                    size_table = allegro_api.models.just_id.JustId(
                                        id = '0', ), 
                                    stock = allegro_api.models.stock.Stock(
                                        available = 56, 
                                        unit = '0', ), 
                                    tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                                        id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', ), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    validation = allegro_api.models.validation.Validation(
                                        errors = [
                                            allegro_api.models.validation_error.ValidationError(
                                                code = '0', 
                                                details = '0', 
                                                message = '0', 
                                                path = '0', 
                                                user_message = '0', )
                                            ], 
                                        validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                ], ), 
                        rates = allegro_api.models.rates.Rates(
                            delivery_cost = 5, 
                            service = 5, ), 
                        recommended = False, 
                        removal = allegro_api.models.removal.Removal(
                            possible_to = '2017-05-17T08:36:57.292+02:00', 
                            request = allegro_api.models.removal_request.RemovalRequest(
                                created_at = '2017-05-17T08:36:57.292+02:00', 
                                message = '0', ), ), )
                    ],
        )

    def testUserRatingListResponse(self):
        """Test UserRatingListResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class BadgeApplicationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'campaign': 'BadgeApplicationCampaign',
        'offer': 'BadgeApplicationOffer',
        'prices': 'BadgeApplicationPrices',
        'purchase_constraints': 'BadgeApplicationPurchaseConstraints'
    }

    attribute_map = {
        'campaign': 'campaign',
        'offer': 'offer',
        'prices': 'prices',
        'purchase_constraints': 'purchaseConstraints'
    }

    def __init__(self, campaign=None, offer=None, prices=None, purchase_constraints=None, local_vars_configuration=None):  # noqa: E501
        """BadgeApplicationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._campaign = None
        self._offer = None
        self._prices = None
        self._purchase_constraints = None
        self.discriminator = None

        self.campaign = campaign
        self.offer = offer
        if prices is not None:
            self.prices = prices
        if purchase_constraints is not None:
            self.purchase_constraints = purchase_constraints

    @property
    def campaign(self):
        """Gets the campaign of this BadgeApplicationRequest.  # noqa: E501


        :return: The campaign of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationCampaign
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """Sets the campaign of this BadgeApplicationRequest.


        :param campaign: The campaign of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationCampaign
        """
        if self.local_vars_configuration.client_side_validation and campaign is None:  # noqa: E501
            raise ValueError("Invalid value for `campaign`, must not be `None`")  # noqa: E501

        self._campaign = campaign

    @property
    def offer(self):
        """Gets the offer of this BadgeApplicationRequest.  # noqa: E501


        :return: The offer of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationOffer
        """
        return self._offer

    @offer.setter
    def offer(self, offer):
        """Sets the offer of this BadgeApplicationRequest.


        :param offer: The offer of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationOffer
        """
        if self.local_vars_configuration.client_side_validation and offer is None:  # noqa: E501
            raise ValueError("Invalid value for `offer`, must not be `None`")  # noqa: E501

        self._offer = offer

    @property
    def prices(self):
        """Gets the prices of this BadgeApplicationRequest.  # noqa: E501


        :return: The prices of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationPrices
        """
        return self._prices

    @prices.setter
    def prices(self, prices):
        """Sets the prices of this BadgeApplicationRequest.


        :param prices: The prices of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationPrices
        """

        self._prices = prices

    @property
    def purchase_constraints(self):
        """Gets the purchase_constraints of this BadgeApplicationRequest.  # noqa: E501


        :return: The purchase_constraints of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationPurchaseConstraints
        """
        return self._purchase_constraints

    @purchase_constraints.setter
    def purchase_constraints(self, purchase_constraints):
        """Sets the purchase_constraints of this BadgeApplicationRequest.


        :param purchase_constraints: The purchase_constraints of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationPurchaseConstraints
        """

        self._purchase_constraints = purchase_constraints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BadgeApplicationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BadgeApplicationRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.inline_response2001_delivery_methods import InlineResponse2001DeliveryMethods  # noqa: E501
from allegro_api.rest import ApiException

class TestInlineResponse2001DeliveryMethods(unittest.TestCase):
    """InlineResponse2001DeliveryMethods unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2001DeliveryMethods
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.inline_response2001_delivery_methods.InlineResponse2001DeliveryMethods()  # noqa: E501
        if include_optional :
            return InlineResponse2001DeliveryMethods(
                id = '0', 
                name = '0', 
                payment_policy = 'IN_ADVANCE', 
                allegro_endorsed = True, 
                shipping_rates_constraints = allegro_api.models.inline_response_200_1_shipping_rates_constraints.inline_response_200_1_shippingRatesConstraints(
                    allowed = True, 
                    max_quantity_per_package = allegro_api.models.inline_response_200_1_shipping_rates_constraints_max_quantity_per_package.inline_response_200_1_shippingRatesConstraints_maxQuantityPerPackage(
                        max = 999999, ), 
                    first_item_rate = allegro_api.models.inline_response_200_1_shipping_rates_constraints_first_item_rate.inline_response_200_1_shippingRatesConstraints_firstItemRate(
                        min = '0.00', 
                        max = '8.99', 
                        currency = 'PLN', ), 
                    next_item_rate = allegro_api.models.inline_response_200_1_shipping_rates_constraints_next_item_rate.inline_response_200_1_shippingRatesConstraints_nextItemRate(
                        min = '0.00', 
                        max = '8.99', 
                        currency = 'PLN', ), 
                    shipping_time = allegro_api.models.inline_response_200_1_shipping_rates_constraints_shipping_time.inline_response_200_1_shippingRatesConstraints_shippingTime(
                        default = allegro_api.models.inline_response_200_1_shipping_rates_constraints_shipping_time_default.inline_response_200_1_shippingRatesConstraints_shippingTime_default(
                            from = 'PT24H', 
                            to = 'PT48H', ), 
                        customizable = True, ), )
            )
        else :
            return InlineResponse2001DeliveryMethods(
        )

    def testInlineResponse2001DeliveryMethods(self):
        """Test InlineResponse2001DeliveryMethods"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_shipping_rates import OfferShippingRates  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferShippingRates(unittest.TestCase):
    """OfferShippingRates unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferShippingRates
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_shipping_rates.OfferShippingRates()  # noqa: E501
        if include_optional :
            return OfferShippingRates(
                rates = [
                    allegro_api.models.shipping_rate.ShippingRate(
                        delivery_method = allegro_api.models.shipping_rate_delivery_method.ShippingRate_deliveryMethod(
                            id = '0', ), 
                        max_quantity_per_package = 1, 
                        first_item_rate = allegro_api.models.shipping_rate_first_item_rate.ShippingRate_firstItemRate(
                            amount = '0', 
                            currency = '0', ), 
                        next_item_rate = allegro_api.models.shipping_rate_next_item_rate.ShippingRate_nextItemRate(
                            amount = '0', 
                            currency = '0', ), 
                        shipping_time = allegro_api.models.shipping_rate_shipping_time.ShippingRate_shippingTime(
                            from = '0', 
                            to = '0', ), )
                    ]
            )
        else :
            return OfferShippingRates(
        )

    def testOfferShippingRates(self):
        """Test OfferShippingRates"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatibility_list_product_based_all_of import CompatibilityListProductBasedAllOf  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibilityListProductBasedAllOf(unittest.TestCase):
    """CompatibilityListProductBasedAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibilityListProductBasedAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatibility_list_product_based_all_of.CompatibilityListProductBasedAllOf()  # noqa: E501
        if include_optional :
            return CompatibilityListProductBasedAllOf(
                id = '460b2511-b786-47b9-9d7e-1f868728cfd6-f103931434fbf4aa06764f3df74d371df23aa138a9cd46dbe570f51af79db1c4-2', 
                items = [
                    allegro_api.models.compatibility_list_item_product_based.CompatibilityListItemProductBased(
                        text = 'AUDI 90 (89, 89Q, 8A, B3) 1988/06-1991/09 2.3 E 20V quattro 170KM/125kW 1501', )
                    ]
            )
        else :
            return CompatibilityListProductBasedAllOf(
                id = '460b2511-b786-47b9-9d7e-1f868728cfd6-f103931434fbf4aa06764f3df74d371df23aa138a9cd46dbe570f51af79db1c4-2',
        )

    def testCompatibilityListProductBasedAllOf(self):
        """Test CompatibilityListProductBasedAllOf"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.checkout_form_invoice_address import CheckoutFormInvoiceAddress  # noqa: E501
from allegro_api.rest import ApiException

class TestCheckoutFormInvoiceAddress(unittest.TestCase):
    """CheckoutFormInvoiceAddress unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckoutFormInvoiceAddress
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.checkout_form_invoice_address.CheckoutFormInvoiceAddress()  # noqa: E501
        if include_optional :
            return CheckoutFormInvoiceAddress(
                street = 'Grunwaldzka 182', 
                city = 'Poznań', 
                zip_code = '60-166', 
                country_code = 'PL', 
                company = allegro_api.models.checkout_form_invoice_address_company.CheckoutFormInvoiceAddressCompany(
                    name = 'Udix Sp. z o.o.', 
                    tax_id = '0', ), 
                natural_person = allegro_api.models.checkout_form_invoice_address_natural_person.CheckoutFormInvoiceAddressNaturalPerson(
                    first_name = 'Jan', 
                    last_name = 'Kowalski', )
            )
        else :
            return CheckoutFormInvoiceAddress(
                street = 'Grunwaldzka 182',
                city = 'Poznań',
                zip_code = '60-166',
                country_code = 'PL',
        )

    def testCheckoutFormInvoiceAddress(self):
        """Test CheckoutFormInvoiceAddress"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ModificationPromotion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bold': 'bool',
        'department_page': 'bool',
        'emphasized': 'bool',
        'emphasized_highlight_bold_package': 'bool',
        'highlight': 'bool'
    }

    attribute_map = {
        'bold': 'bold',
        'department_page': 'departmentPage',
        'emphasized': 'emphasized',
        'emphasized_highlight_bold_package': 'emphasizedHighlightBoldPackage',
        'highlight': 'highlight'
    }

    def __init__(self, bold=None, department_page=None, emphasized=None, emphasized_highlight_bold_package=None, highlight=None, local_vars_configuration=None):  # noqa: E501
        """ModificationPromotion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bold = None
        self._department_page = None
        self._emphasized = None
        self._emphasized_highlight_bold_package = None
        self._highlight = None
        self.discriminator = None

        if bold is not None:
            self.bold = bold
        if department_page is not None:
            self.department_page = department_page
        if emphasized is not None:
            self.emphasized = emphasized
        if emphasized_highlight_bold_package is not None:
            self.emphasized_highlight_bold_package = emphasized_highlight_bold_package
        if highlight is not None:
            self.highlight = highlight

    @property
    def bold(self):
        """Gets the bold of this ModificationPromotion.  # noqa: E501

        Bold flag: true, false, null  # noqa: E501

        :return: The bold of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this ModificationPromotion.

        Bold flag: true, false, null  # noqa: E501

        :param bold: The bold of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._bold = bold

    @property
    def department_page(self):
        """Gets the department_page of this ModificationPromotion.  # noqa: E501

        DepartmentPage flag: true, false, null  # noqa: E501

        :return: The department_page of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._department_page

    @department_page.setter
    def department_page(self, department_page):
        """Sets the department_page of this ModificationPromotion.

        DepartmentPage flag: true, false, null  # noqa: E501

        :param department_page: The department_page of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._department_page = department_page

    @property
    def emphasized(self):
        """Gets the emphasized of this ModificationPromotion.  # noqa: E501

        Emphasized flag: true, false, null  # noqa: E501

        :return: The emphasized of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._emphasized

    @emphasized.setter
    def emphasized(self, emphasized):
        """Sets the emphasized of this ModificationPromotion.

        Emphasized flag: true, false, null  # noqa: E501

        :param emphasized: The emphasized of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._emphasized = emphasized

    @property
    def emphasized_highlight_bold_package(self):
        """Gets the emphasized_highlight_bold_package of this ModificationPromotion.  # noqa: E501

        EmphasizedHighlightBoldPackage flag: true, false, null  # noqa: E501

        :return: The emphasized_highlight_bold_package of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._emphasized_highlight_bold_package

    @emphasized_highlight_bold_package.setter
    def emphasized_highlight_bold_package(self, emphasized_highlight_bold_package):
        """Sets the emphasized_highlight_bold_package of this ModificationPromotion.

        EmphasizedHighlightBoldPackage flag: true, false, null  # noqa: E501

        :param emphasized_highlight_bold_package: The emphasized_highlight_bold_package of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._emphasized_highlight_bold_package = emphasized_highlight_bold_package

    @property
    def highlight(self):
        """Gets the highlight of this ModificationPromotion.  # noqa: E501

        Highlight flag: true, false, null  # noqa: E501

        :return: The highlight of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._highlight

    @highlight.setter
    def highlight(self, highlight):
        """Sets the highlight of this ModificationPromotion.

        Highlight flag: true, false, null  # noqa: E501

        :param highlight: The highlight of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._highlight = highlight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModificationPromotion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModificationPromotion):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.classifieds_api import ClassifiedsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestClassifiedsApi(unittest.TestCase):
    """ClassifiedsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.classifieds_api.ClassifiedsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_assign_classified_packages_using_put(self):
        """Test case for assign_classified_packages_using_put

        Assign packages to a classified  # noqa: E501
        """
        pass

    def test_get_classified_package_configuration_using_get(self):
        """Test case for get_classified_package_configuration_using_get

        Get the configuration of a package  # noqa: E501
        """
        pass

    def test_get_classified_package_configurations_for_category_using_get(self):
        """Test case for get_classified_package_configurations_for_category_using_get

        Get configurations of packages  # noqa: E501
        """
        pass

    def test_get_classified_packages_using_get(self):
        """Test case for get_classified_packages_using_get

        Get classified packages assigned to an offer  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CheckoutForm(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'message_to_seller': 'str',
        'buyer': 'CheckoutFormBuyerReference',
        'payment': 'CheckoutFormPaymentReference',
        'status': 'CheckoutFormStatus',
        'fulfillment': 'CheckoutFormFulfillment',
        'delivery': 'CheckoutFormDeliveryReference',
        'invoice': 'CheckoutFormInvoiceInfo',
        'line_items': 'list[CheckoutFormLineItem]',
        'surcharges': 'list[CheckoutFormPaymentReference]',
        'discounts': 'list[CheckoutFormDiscount]',
        'summary': 'CheckoutFormSummary',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'message_to_seller': 'messageToSeller',
        'buyer': 'buyer',
        'payment': 'payment',
        'status': 'status',
        'fulfillment': 'fulfillment',
        'delivery': 'delivery',
        'invoice': 'invoice',
        'line_items': 'lineItems',
        'surcharges': 'surcharges',
        'discounts': 'discounts',
        'summary': 'summary',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, message_to_seller=None, buyer=None, payment=None, status=None, fulfillment=None, delivery=None, invoice=None, line_items=None, surcharges=None, discounts=None, summary=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """CheckoutForm - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._message_to_seller = None
        self._buyer = None
        self._payment = None
        self._status = None
        self._fulfillment = None
        self._delivery = None
        self._invoice = None
        self._line_items = None
        self._surcharges = None
        self._discounts = None
        self._summary = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        if message_to_seller is not None:
            self.message_to_seller = message_to_seller
        self.buyer = buyer
        if payment is not None:
            self.payment = payment
        self.status = status
        if fulfillment is not None:
            self.fulfillment = fulfillment
        if delivery is not None:
            self.delivery = delivery
        if invoice is not None:
            self.invoice = invoice
        self.line_items = line_items
        self.surcharges = surcharges
        self.discounts = discounts
        self.summary = summary
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this CheckoutForm.  # noqa: E501

        Checkout form id  # noqa: E501

        :return: The id of this CheckoutForm.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CheckoutForm.

        Checkout form id  # noqa: E501

        :param id: The id of this CheckoutForm.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def message_to_seller(self):
        """Gets the message_to_seller of this CheckoutForm.  # noqa: E501

        Message from buyer to seller  # noqa: E501

        :return: The message_to_seller of this CheckoutForm.  # noqa: E501
        :rtype: str
        """
        return self._message_to_seller

    @message_to_seller.setter
    def message_to_seller(self, message_to_seller):
        """Sets the message_to_seller of this CheckoutForm.

        Message from buyer to seller  # noqa: E501

        :param message_to_seller: The message_to_seller of this CheckoutForm.  # noqa: E501
        :type: str
        """

        self._message_to_seller = message_to_seller

    @property
    def buyer(self):
        """Gets the buyer of this CheckoutForm.  # noqa: E501


        :return: The buyer of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormBuyerReference
        """
        return self._buyer

    @buyer.setter
    def buyer(self, buyer):
        """Sets the buyer of this CheckoutForm.


        :param buyer: The buyer of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormBuyerReference
        """
        if self.local_vars_configuration.client_side_validation and buyer is None:  # noqa: E501
            raise ValueError("Invalid value for `buyer`, must not be `None`")  # noqa: E501

        self._buyer = buyer

    @property
    def payment(self):
        """Gets the payment of this CheckoutForm.  # noqa: E501


        :return: The payment of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormPaymentReference
        """
        return self._payment

    @payment.setter
    def payment(self, payment):
        """Sets the payment of this CheckoutForm.


        :param payment: The payment of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormPaymentReference
        """

        self._payment = payment

    @property
    def status(self):
        """Gets the status of this CheckoutForm.  # noqa: E501


        :return: The status of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckoutForm.


        :param status: The status of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormStatus
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def fulfillment(self):
        """Gets the fulfillment of this CheckoutForm.  # noqa: E501


        :return: The fulfillment of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormFulfillment
        """
        return self._fulfillment

    @fulfillment.setter
    def fulfillment(self, fulfillment):
        """Sets the fulfillment of this CheckoutForm.


        :param fulfillment: The fulfillment of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormFulfillment
        """

        self._fulfillment = fulfillment

    @property
    def delivery(self):
        """Gets the delivery of this CheckoutForm.  # noqa: E501


        :return: The delivery of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormDeliveryReference
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this CheckoutForm.


        :param delivery: The delivery of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormDeliveryReference
        """

        self._delivery = delivery

    @property
    def invoice(self):
        """Gets the invoice of this CheckoutForm.  # noqa: E501


        :return: The invoice of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormInvoiceInfo
        """
        return self._invoice

    @invoice.setter
    def invoice(self, invoice):
        """Sets the invoice of this CheckoutForm.


        :param invoice: The invoice of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormInvoiceInfo
        """

        self._invoice = invoice

    @property
    def line_items(self):
        """Gets the line_items of this CheckoutForm.  # noqa: E501


        :return: The line_items of this CheckoutForm.  # noqa: E501
        :rtype: list[CheckoutFormLineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this CheckoutForm.


        :param line_items: The line_items of this CheckoutForm.  # noqa: E501
        :type: list[CheckoutFormLineItem]
        """
        if self.local_vars_configuration.client_side_validation and line_items is None:  # noqa: E501
            raise ValueError("Invalid value for `line_items`, must not be `None`")  # noqa: E501

        self._line_items = line_items

    @property
    def surcharges(self):
        """Gets the surcharges of this CheckoutForm.  # noqa: E501


        :return: The surcharges of this CheckoutForm.  # noqa: E501
        :rtype: list[CheckoutFormPaymentReference]
        """
        return self._surcharges

    @surcharges.setter
    def surcharges(self, surcharges):
        """Sets the surcharges of this CheckoutForm.


        :param surcharges: The surcharges of this CheckoutForm.  # noqa: E501
        :type: list[CheckoutFormPaymentReference]
        """
        if self.local_vars_configuration.client_side_validation and surcharges is None:  # noqa: E501
            raise ValueError("Invalid value for `surcharges`, must not be `None`")  # noqa: E501

        self._surcharges = surcharges

    @property
    def discounts(self):
        """Gets the discounts of this CheckoutForm.  # noqa: E501


        :return: The discounts of this CheckoutForm.  # noqa: E501
        :rtype: list[CheckoutFormDiscount]
        """
        return self._discounts

    @discounts.setter
    def discounts(self, discounts):
        """Sets the discounts of this CheckoutForm.


        :param discounts: The discounts of this CheckoutForm.  # noqa: E501
        :type: list[CheckoutFormDiscount]
        """
        if self.local_vars_configuration.client_side_validation and discounts is None:  # noqa: E501
            raise ValueError("Invalid value for `discounts`, must not be `None`")  # noqa: E501

        self._discounts = discounts

    @property
    def summary(self):
        """Gets the summary of this CheckoutForm.  # noqa: E501


        :return: The summary of this CheckoutForm.  # noqa: E501
        :rtype: CheckoutFormSummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this CheckoutForm.


        :param summary: The summary of this CheckoutForm.  # noqa: E501
        :type: CheckoutFormSummary
        """
        if self.local_vars_configuration.client_side_validation and summary is None:  # noqa: E501
            raise ValueError("Invalid value for `summary`, must not be `None`")  # noqa: E501

        self._summary = summary

    @property
    def updated_at(self):
        """Gets the updated_at of this CheckoutForm.  # noqa: E501

        Provided in [ISO 8601 format](link: https://en.wikipedia.org/wiki/ISO_8601).  # noqa: E501

        :return: The updated_at of this CheckoutForm.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CheckoutForm.

        Provided in [ISO 8601 format](link: https://en.wikipedia.org/wiki/ISO_8601).  # noqa: E501

        :param updated_at: The updated_at of this CheckoutForm.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckoutForm):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckoutForm):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class OfferVariantsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_or_update_variant_set(self, set_id, variant_set, **kwargs):  # noqa: E501
        """[BETA] Create or update variant set  # noqa: E501

        [BETA] Use this resource to create or update variant set.   A valid variant set must consist of three required elements:  - name:    - it can't be blank and must not be longer than 50 characters  - parameters:    - it should contain parameter identifiers used for offer grouping    - parameter identifiers from the offers and special `color/pattern` value (for grouping via image) are permitted    - it must contain at least one element (up to 2)  - offers:    - it must contain at least 2 offers (500 at most)    - `colorPattern` value must be set for every offer if `color/pattern` parameter is used    - `colorPattern` value can't be blank and must not be longer than 50 characters    - `colorPattern` can take arbitrary string value like `red`, `b323592c-522f-4ec1-b9ea-3764538e0ac4` (UUID), etc.    - offers having the same image should have identical `colorPattern` value    Let's assume we have 4 offers:    - offer with id 2 having an image of a red t-shirt and S as a value of parameter with id 21    - offer with id 3 having an image of a red t-shirt and M as a value of parameter with id 21    - offer with id 4 having an image of a blue t-shirt and S as a value of parameter with id 21    - offer with id 5 having an image of a blue t-shirt and M as a value of parameter with id 21    You can build a variant set by grouping offers using combination of available parameters - examples are available in <i>Request samples</i>.    More general information about variant sets can be found [here](https://allegro.pl/pomoc/faq/wielowariantowosc-jak-polaczyc-oferty-xGgaOByGgTb#dodatkowe-informacje),  more information about variant sets API can be found <a href=\"../../news/2018-07-09-wielowariantowosc/#03\" target=\"_blank\">here</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_variant_set(set_id, variant_set, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str set_id: Variant set identifier. (required)
        :param VariantSet variant_set: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_or_update_variant_set_with_http_info(set_id, variant_set, **kwargs)  # noqa: E501

    def create_or_update_variant_set_with_http_info(self, set_id, variant_set, **kwargs):  # noqa: E501
        """[BETA] Create or update variant set  # noqa: E501

        [BETA] Use this resource to create or update variant set.   A valid variant set must consist of three required elements:  - name:    - it can't be blank and must not be longer than 50 characters  - parameters:    - it should contain parameter identifiers used for offer grouping    - parameter identifiers from the offers and special `color/pattern` value (for grouping via image) are permitted    - it must contain at least one element (up to 2)  - offers:    - it must contain at least 2 offers (500 at most)    - `colorPattern` value must be set for every offer if `color/pattern` parameter is used    - `colorPattern` value can't be blank and must not be longer than 50 characters    - `colorPattern` can take arbitrary string value like `red`, `b323592c-522f-4ec1-b9ea-3764538e0ac4` (UUID), etc.    - offers having the same image should have identical `colorPattern` value    Let's assume we have 4 offers:    - offer with id 2 having an image of a red t-shirt and S as a value of parameter with id 21    - offer with id 3 having an image of a red t-shirt and M as a value of parameter with id 21    - offer with id 4 having an image of a blue t-shirt and S as a value of parameter with id 21    - offer with id 5 having an image of a blue t-shirt and M as a value of parameter with id 21    You can build a variant set by grouping offers using combination of available parameters - examples are available in <i>Request samples</i>.    More general information about variant sets can be found [here](https://allegro.pl/pomoc/faq/wielowariantowosc-jak-polaczyc-oferty-xGgaOByGgTb#dodatkowe-informacje),  more information about variant sets API can be found <a href=\"../../news/2018-07-09-wielowariantowosc/#03\" target=\"_blank\">here</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_variant_set_with_http_info(set_id, variant_set, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str set_id: Variant set identifier. (required)
        :param VariantSet variant_set: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['set_id', 'variant_set']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_or_update_variant_set" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'set_id' is set
        if self.api_client.client_side_validation and ('set_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['set_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `set_id` when calling `create_or_update_variant_set`")  # noqa: E501
        # verify the required parameter 'variant_set' is set
        if self.api_client.client_side_validation and ('variant_set' not in local_var_params or  # noqa: E501
                                                        local_var_params['variant_set'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `variant_set` when calling `create_or_update_variant_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'set_id' in local_var_params:
            path_params['setId'] = local_var_params['set_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variant_set' in local_var_params:
            body_params = local_var_params['variant_set']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-variants/{setId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_variant_set(self, set_id, **kwargs):  # noqa: E501
        """[BETA] Delete a variant set  # noqa: E501

        [BETA] Use this resource to delete variant set by id. Offers included in variant set will not be stopped or modified by this operation. <a href=\"../../news/2018-07-09-wielowariantowosc/#05\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variant_set(set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str set_id: Variant set identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_variant_set_with_http_info(set_id, **kwargs)  # noqa: E501

    def delete_variant_set_with_http_info(self, set_id, **kwargs):  # noqa: E501
        """[BETA] Delete a variant set  # noqa: E501

        [BETA] Use this resource to delete variant set by id. Offers included in variant set will not be stopped or modified by this operation. <a href=\"../../news/2018-07-09-wielowariantowosc/#05\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variant_set_with_http_info(set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str set_id: Variant set identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['set_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_variant_set" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'set_id' is set
        if self.api_client.client_side_validation and ('set_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['set_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `set_id` when calling `delete_variant_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'set_id' in local_var_params:
            path_params['setId'] = local_var_params['set_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-variants/{setId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variant_set(self, set_id, **kwargs):  # noqa: E501
        """[BETA] Get a variant set  # noqa: E501

        [BETA] Use this resource to get variant set by set id. <a href=\"../../news/2018-07-09-wielowariantowosc/#04\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variant_set(set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str set_id: Variant set identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VariantSet
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_variant_set_with_http_info(set_id, **kwargs)  # noqa: E501

    def get_variant_set_with_http_info(self, set_id, **kwargs):  # noqa: E501
        """[BETA] Get a variant set  # noqa: E501

        [BETA] Use this resource to get variant set by set id. <a href=\"../../news/2018-07-09-wielowariantowosc/#04\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variant_set_with_http_info(set_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str set_id: Variant set identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VariantSet, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['set_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variant_set" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'set_id' is set
        if self.api_client.client_side_validation and ('set_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['set_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `set_id` when calling `get_variant_set`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'set_id' in local_var_params:
            path_params['setId'] = local_var_params['set_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-variants/{setId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VariantSet',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variant_sets(self, user_id, **kwargs):  # noqa: E501
        """[BETA] Get the user's variant sets  # noqa: E501

        [BETA] Use this resource to get created variant sets. The returned variant sets are ordered by name. <a href=\"../../news/2018-07-09-wielowariantowosc/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variant_sets(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: Filter by user id, you are allowed to get your variant sets only. (required)
        :param int offset: Index of first returned variant set.
        :param int limit: Maximum number of returned variant sets.
        :param str query: Filter variant sets by name or offer id.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VariantSets
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_variant_sets_with_http_info(user_id, **kwargs)  # noqa: E501

    def get_variant_sets_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """[BETA] Get the user's variant sets  # noqa: E501

        [BETA] Use this resource to get created variant sets. The returned variant sets are ordered by name. <a href=\"../../news/2018-07-09-wielowariantowosc/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variant_sets_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: Filter by user id, you are allowed to get your variant sets only. (required)
        :param int offset: Index of first returned variant set.
        :param int limit: Maximum number of returned variant sets.
        :param str query: Filter variant sets by name or offer id.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VariantSets, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'offset', 'limit', 'query']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variant_sets" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `get_variant_sets`")  # noqa: E501

        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] > 9950:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_variant_sets`, must be a value less than or equal to `9950`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_variant_sets`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 50:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_variant_sets`, must be a value less than or equal to `50`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_variant_sets`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('query' in local_var_params and  # noqa: E501
                                                        len(local_var_params['query']) > 50):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `query` when calling `get_variant_sets`, length must be less than or equal to `50`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user.id', local_var_params['user_id']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'query' in local_var_params and local_var_params['query'] is not None:  # noqa: E501
            query_params.append(('query', local_var_params['query']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.beta.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-variants', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='VariantSets',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.badges_list import BadgesList  # noqa: E501
from allegro_api.rest import ApiException

class TestBadgesList(unittest.TestCase):
    """BadgesList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BadgesList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.badges_list.BadgesList()  # noqa: E501
        if include_optional :
            return BadgesList(
                badges = [
                    allegro_api.models.badge.Badge(
                        offer = allegro_api.models.badge_offer.BadgeOffer(
                            id = '987654321', ), 
                        campaign = allegro_api.models.offer_badge_campaign.OfferBadgeCampaign(
                            id = 'BARGAIN', 
                            name = 'Strefa Okazji', ), 
                        publication = {"type":"UNTIL","to":"2012-12-03T10:15:30.000Z"}, 
                        prices = allegro_api.models.badge_prices.BadgePrices(
                            market = allegro_api.models.badge_application_market_price.BadgeApplicationMarketPrice(
                                amount = '1.23', 
                                currency = 'PLN', ), 
                            bargain = allegro_api.models.badge_application_bargain_price.BadgeApplicationBargainPrice(
                                amount = '1.23', 
                                currency = 'PLN', ), ), 
                        process = allegro_api.models.badge_process.BadgeProcess(
                            status = 'IN_VERIFICATION', 
                            rejection_reasons = [
                                allegro_api.models.rejection_reason.RejectionReason(
                                    code = '0', 
                                    messages = [
                                        allegro_api.models.badge_application_rejection_reason_message.BadgeApplicationRejectionReasonMessage(
                                            text = 'See requirements.', 
                                            link = 'https://allegro.pl/regulamin/pl', )
                                        ], )
                                ], ), )
                    ]
            )
        else :
            return BadgesList(
                badges = [
                    allegro_api.models.badge.Badge(
                        offer = allegro_api.models.badge_offer.BadgeOffer(
                            id = '987654321', ), 
                        campaign = allegro_api.models.offer_badge_campaign.OfferBadgeCampaign(
                            id = 'BARGAIN', 
                            name = 'Strefa Okazji', ), 
                        publication = {"type":"UNTIL","to":"2012-12-03T10:15:30.000Z"}, 
                        prices = allegro_api.models.badge_prices.BadgePrices(
                            market = allegro_api.models.badge_application_market_price.BadgeApplicationMarketPrice(
                                amount = '1.23', 
                                currency = 'PLN', ), 
                            bargain = allegro_api.models.badge_application_bargain_price.BadgeApplicationBargainPrice(
                                amount = '1.23', 
                                currency = 'PLN', ), ), 
                        process = allegro_api.models.badge_process.BadgeProcess(
                            status = 'IN_VERIFICATION', 
                            rejection_reasons = [
                                allegro_api.models.rejection_reason.RejectionReason(
                                    code = '0', 
                                    messages = [
                                        allegro_api.models.badge_application_rejection_reason_message.BadgeApplicationRejectionReasonMessage(
                                            text = 'See requirements.', 
                                            link = 'https://allegro.pl/regulamin/pl', )
                                        ], )
                                ], ), )
                    ],
        )

    def testBadgesList(self):
        """Test BadgesList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class BillingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_billing_entries(self, **kwargs):  # noqa: E501
        """Get a list of billing entries  # noqa: E501

        The billing entries are sorted in a descending order (newest first) by date on which they occurred.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_entries(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param datetime occurred_at_gte: Date from which billing entries are filtered. If occurredAt.lte is also set, occurredAt.gte cannot be later.
        :param datetime occurred_at_lte: Date to which billing entries are filtered. If occurredAt.gte is also set, occurredAt.lte cannot be earlier.
        :param list[str] type_id: List of billing types by which billing entries are filtered.
        :param str offer_id: Offer ID by which billing entries are filtered.
        :param int limit: Number of returned operations.
        :param int offset: Index of the first returned payment operation from all search results.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_billing_entries_with_http_info(**kwargs)  # noqa: E501

    def get_billing_entries_with_http_info(self, **kwargs):  # noqa: E501
        """Get a list of billing entries  # noqa: E501

        The billing entries are sorted in a descending order (newest first) by date on which they occurred.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_entries_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param datetime occurred_at_gte: Date from which billing entries are filtered. If occurredAt.lte is also set, occurredAt.gte cannot be later.
        :param datetime occurred_at_lte: Date to which billing entries are filtered. If occurredAt.gte is also set, occurredAt.lte cannot be earlier.
        :param list[str] type_id: List of billing types by which billing entries are filtered.
        :param str offer_id: Offer ID by which billing entries are filtered.
        :param int limit: Number of returned operations.
        :param int offset: Index of the first returned payment operation from all search results.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['occurred_at_gte', 'occurred_at_lte', 'type_id', 'offer_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_entries" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_billing_entries`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_billing_entries`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_billing_entries`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_billing_entries`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'occurred_at_gte' in local_var_params and local_var_params['occurred_at_gte'] is not None:  # noqa: E501
            query_params.append(('occurredAt.gte', local_var_params['occurred_at_gte']))  # noqa: E501
        if 'occurred_at_lte' in local_var_params and local_var_params['occurred_at_lte'] is not None:  # noqa: E501
            query_params.append(('occurredAt.lte', local_var_params['occurred_at_lte']))  # noqa: E501
        if 'type_id' in local_var_params and local_var_params['type_id'] is not None:  # noqa: E501
            query_params.append(('type.id', local_var_params['type_id']))  # noqa: E501
            collection_formats['type.id'] = 'multi'  # noqa: E501
        if 'offer_id' in local_var_params and local_var_params['offer_id'] is not None:  # noqa: E501
            query_params.append(('offer.id', local_var_params['offer_id']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/billing/billing-entries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.promotion_campaigns_api import PromotionCampaignsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestPromotionCampaignsApi(unittest.TestCase):
    """PromotionCampaignsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.promotion_campaigns_api.PromotionCampaignsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_promotion_to_campaign_using_post(self):
        """Test case for add_promotion_to_campaign_using_post

        Create an application for a promotion campaign  # noqa: E501
        """
        pass

    def test_delete_campaign_from_promotion_using_delete(self):
        """Test case for delete_campaign_from_promotion_using_delete

        Delete a campaign in a promotion  # noqa: E501
        """
        pass

    def test_delete_promotion_campaign_application_using_delete(self):
        """Test case for delete_promotion_campaign_application_using_delete

        Delete an application for promotion campaign  # noqa: E501
        """
        pass

    def test_get_promotion_campaign_application_using_get(self):
        """Test case for get_promotion_campaign_application_using_get

        Get an application for promotion campaign  # noqa: E501
        """
        pass

    def test_get_promotion_campaigns_using_get(self):
        """Test case for get_promotion_campaigns_using_get

        Get the user's promotion campaigns  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class MyBidResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max_amount': 'MaxPrice',
        'minimal_price_met': 'bool',
        'high_bidder': 'bool',
        'auction': 'AuctionDetails'
    }

    attribute_map = {
        'max_amount': 'maxAmount',
        'minimal_price_met': 'minimalPriceMet',
        'high_bidder': 'highBidder',
        'auction': 'auction'
    }

    def __init__(self, max_amount=None, minimal_price_met=None, high_bidder=None, auction=None, local_vars_configuration=None):  # noqa: E501
        """MyBidResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._max_amount = None
        self._minimal_price_met = None
        self._high_bidder = None
        self._auction = None
        self.discriminator = None

        self.max_amount = max_amount
        if minimal_price_met is not None:
            self.minimal_price_met = minimal_price_met
        self.high_bidder = high_bidder
        self.auction = auction

    @property
    def max_amount(self):
        """Gets the max_amount of this MyBidResponse.  # noqa: E501


        :return: The max_amount of this MyBidResponse.  # noqa: E501
        :rtype: MaxPrice
        """
        return self._max_amount

    @max_amount.setter
    def max_amount(self, max_amount):
        """Sets the max_amount of this MyBidResponse.


        :param max_amount: The max_amount of this MyBidResponse.  # noqa: E501
        :type: MaxPrice
        """
        if self.local_vars_configuration.client_side_validation and max_amount is None:  # noqa: E501
            raise ValueError("Invalid value for `max_amount`, must not be `None`")  # noqa: E501

        self._max_amount = max_amount

    @property
    def minimal_price_met(self):
        """Gets the minimal_price_met of this MyBidResponse.  # noqa: E501

        This indicates if the minimal price of the auction has been met or is not set at all. A minimal price can be set by the seller and is the minimum amount the seller is willing to sell the item for. If the highest bid is not higher than the minimal price when the auction ends, the listing ends and the item is not sold.  # noqa: E501

        :return: The minimal_price_met of this MyBidResponse.  # noqa: E501
        :rtype: bool
        """
        return self._minimal_price_met

    @minimal_price_met.setter
    def minimal_price_met(self, minimal_price_met):
        """Sets the minimal_price_met of this MyBidResponse.

        This indicates if the minimal price of the auction has been met or is not set at all. A minimal price can be set by the seller and is the minimum amount the seller is willing to sell the item for. If the highest bid is not higher than the minimal price when the auction ends, the listing ends and the item is not sold.  # noqa: E501

        :param minimal_price_met: The minimal_price_met of this MyBidResponse.  # noqa: E501
        :type: bool
        """

        self._minimal_price_met = minimal_price_met

    @property
    def high_bidder(self):
        """Gets the high_bidder of this MyBidResponse.  # noqa: E501

        Is this bid currently winning?  # noqa: E501

        :return: The high_bidder of this MyBidResponse.  # noqa: E501
        :rtype: bool
        """
        return self._high_bidder

    @high_bidder.setter
    def high_bidder(self, high_bidder):
        """Sets the high_bidder of this MyBidResponse.

        Is this bid currently winning?  # noqa: E501

        :param high_bidder: The high_bidder of this MyBidResponse.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and high_bidder is None:  # noqa: E501
            raise ValueError("Invalid value for `high_bidder`, must not be `None`")  # noqa: E501

        self._high_bidder = high_bidder

    @property
    def auction(self):
        """Gets the auction of this MyBidResponse.  # noqa: E501


        :return: The auction of this MyBidResponse.  # noqa: E501
        :rtype: AuctionDetails
        """
        return self._auction

    @auction.setter
    def auction(self, auction):
        """Sets the auction of this MyBidResponse.


        :param auction: The auction of this MyBidResponse.  # noqa: E501
        :type: AuctionDetails
        """
        if self.local_vars_configuration.client_side_validation and auction is None:  # noqa: E501
            raise ValueError("Invalid value for `auction`, must not be `None`")  # noqa: E501

        self._auction = auction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MyBidResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MyBidResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.sale_product_response_dto import SaleProductResponseDto  # noqa: E501
from allegro_api.rest import ApiException

class TestSaleProductResponseDto(unittest.TestCase):
    """SaleProductResponseDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SaleProductResponseDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.sale_product_response_dto.SaleProductResponseDto()  # noqa: E501
        if include_optional :
            return SaleProductResponseDto(
                id = '0', 
                name = '0', 
                category = allegro_api.models.category.Category(
                    id = '0', ), 
                eans = [
                    '0'
                    ], 
                images = [
                    allegro_api.models.image_url.ImageUrl(
                        url = '0', )
                    ], 
                parameters = [
                    allegro_api.models.product_parameter.ProductParameter(
                        id = '0', 
                        range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                            from = '0', 
                            to = '0', ), 
                        values = [
                            '0'
                            ], 
                        values_ids = [
                            '0'
                            ], 
                        values_labels = [
                            '0'
                            ], 
                        unit = '0', 
                        options = [
                            allegro_api.models.product_parameter_options.ProductParameter_options(
                                identifies_product = True, )
                            ], )
                    ]
            )
        else :
            return SaleProductResponseDto(
                id = '0',
                name = '0',
                category = allegro_api.models.category.Category(
                    id = '0', ),
        )

    def testSaleProductResponseDto(self):
        """Test SaleProductResponseDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OfferRating(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'average_score': 'str',
        'score_distribution': 'list[OfferRatingScoreDistribution]',
        'total_responses': 'int',
        'size_feedback': 'list[OfferRatingSizeFeedback]'
    }

    attribute_map = {
        'average_score': 'averageScore',
        'score_distribution': 'scoreDistribution',
        'total_responses': 'totalResponses',
        'size_feedback': 'sizeFeedback'
    }

    def __init__(self, average_score=None, score_distribution=None, total_responses=None, size_feedback=None, local_vars_configuration=None):  # noqa: E501
        """OfferRating - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._average_score = None
        self._score_distribution = None
        self._total_responses = None
        self._size_feedback = None
        self.discriminator = None

        if average_score is not None:
            self.average_score = average_score
        if score_distribution is not None:
            self.score_distribution = score_distribution
        if total_responses is not None:
            self.total_responses = total_responses
        if size_feedback is not None:
            self.size_feedback = size_feedback

    @property
    def average_score(self):
        """Gets the average_score of this OfferRating.  # noqa: E501

        Average score of offer rating.  # noqa: E501

        :return: The average_score of this OfferRating.  # noqa: E501
        :rtype: str
        """
        return self._average_score

    @average_score.setter
    def average_score(self, average_score):
        """Sets the average_score of this OfferRating.

        Average score of offer rating.  # noqa: E501

        :param average_score: The average_score of this OfferRating.  # noqa: E501
        :type: str
        """

        self._average_score = average_score

    @property
    def score_distribution(self):
        """Gets the score_distribution of this OfferRating.  # noqa: E501

        List score distribution with count.  # noqa: E501

        :return: The score_distribution of this OfferRating.  # noqa: E501
        :rtype: list[OfferRatingScoreDistribution]
        """
        return self._score_distribution

    @score_distribution.setter
    def score_distribution(self, score_distribution):
        """Sets the score_distribution of this OfferRating.

        List score distribution with count.  # noqa: E501

        :param score_distribution: The score_distribution of this OfferRating.  # noqa: E501
        :type: list[OfferRatingScoreDistribution]
        """

        self._score_distribution = score_distribution

    @property
    def total_responses(self):
        """Gets the total_responses of this OfferRating.  # noqa: E501

        Number of total responses.  # noqa: E501

        :return: The total_responses of this OfferRating.  # noqa: E501
        :rtype: int
        """
        return self._total_responses

    @total_responses.setter
    def total_responses(self, total_responses):
        """Sets the total_responses of this OfferRating.

        Number of total responses.  # noqa: E501

        :param total_responses: The total_responses of this OfferRating.  # noqa: E501
        :type: int
        """

        self._total_responses = total_responses

    @property
    def size_feedback(self):
        """Gets the size_feedback of this OfferRating.  # noqa: E501

        List of size feedback.  # noqa: E501

        :return: The size_feedback of this OfferRating.  # noqa: E501
        :rtype: list[OfferRatingSizeFeedback]
        """
        return self._size_feedback

    @size_feedback.setter
    def size_feedback(self, size_feedback):
        """Sets the size_feedback of this OfferRating.

        List of size feedback.  # noqa: E501

        :param size_feedback: The size_feedback of this OfferRating.  # noqa: E501
        :type: list[OfferRatingSizeFeedback]
        """

        self._size_feedback = size_feedback

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferRating):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OfferRating):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.parameters_for_preview_price import ParametersForPreviewPrice  # noqa: E501
from allegro_api.rest import ApiException

class TestParametersForPreviewPrice(unittest.TestCase):
    """ParametersForPreviewPrice unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ParametersForPreviewPrice
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.parameters_for_preview_price.ParametersForPreviewPrice()  # noqa: E501
        if include_optional :
            return ParametersForPreviewPrice(
                category = allegro_api.models.category.Category(
                    id = '0', ), 
                condition = 'NEW', 
                duration = 'PT72H', 
                has_any_quantity = True, 
                number_of_big_photos = 56, 
                number_of_photos = 56, 
                quantity = 56, 
                shop = False, 
                sold_quantity = 56, 
                type = 'shop', 
                unit_price = 1.337, 
                bold = True, 
                highlight = True, 
                department_page = True, 
                emphasized = True, 
                emphasized_highlight_bold_package = True, 
                multi_variant = True
            )
        else :
            return ParametersForPreviewPrice(
                category = allegro_api.models.category.Category(
                    id = '0', ),
                unit_price = 1.337,
        )

    def testParametersForPreviewPrice(self):
        """Test ParametersForPreviewPrice"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.change_price import ChangePrice  # noqa: E501
from allegro_api.rest import ApiException

class TestChangePrice(unittest.TestCase):
    """ChangePrice unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ChangePrice
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.change_price.ChangePrice()  # noqa: E501
        if include_optional :
            return ChangePrice(
                id = '6365996a-6cae-11e9-a923-1681be663d3e', 
                input = allegro_api.models.change_price_input.ChangePriceInput(
                    buy_now_price = allegro_api.models.price.Price(
                        amount = '123.45', 
                        currency = 'PLN', ), ), 
                output = allegro_api.models.command_output.CommandOutput(
                    status = 'QUEUEING', 
                    errors = [
                        allegro_api.models.error.Error(
                            code = 'NotAcceptableException', 
                            details = '0', 
                            message = 'Not acceptable representation requested. Please check 'Accept' request header', 
                            path = '0', 
                            user_message = 'The request contains incorrect data. Contact the author of the application.', )
                        ], )
            )
        else :
            return ChangePrice(
                input = allegro_api.models.change_price_input.ChangePriceInput(
                    buy_now_price = allegro_api.models.price.Price(
                        amount = '123.45', 
                        currency = 'PLN', ), ),
        )

    def testChangePrice(self):
        """Test ChangePrice"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
